@@ -73,15 +73,25 @@ class TcsClient:
     def __init__(self,
                  host: str,
                  port: int,
-                 timeout: float = 1.5):
+                 timeout: float = 1.5,
+                 max_tx_retries=12,
+                 max_rx_retries=3,
+                 max_reconnect_attempts=0,
+                 max_reconnect_on_message=5):
         """
         The function `__init__` initializes the class `TcsClient` by setting the host, port, and
-        timeout, and then initializing the `SclnClient` object, and then calling the `infoa` function.
+        timeout, and then initializing the `SclnClient` object, and then calling the `infoa` function
 
         Args:
           host (str): The IP address of the TCS
           port (int): The port number to connect to.
           timeout (float): The default timeout to tx/rx commands
+          max_tx_retries: The number of times to retry sending a command to the TCS. Defaults to 12
+          max_rx_retries: The number of times to retry receiving a response from the TCS. Defaults to 3
+          max_reconnect_attempts: The number of times to attempt to reconnect to the TCS before giving
+        up. Defaults to 0 (no limit)
+          max_reconnect_on_message: The maximum number of times to attempt to reconnect to the TCS when
+        a message is received. Defaults to 5
         """
         # External Inputs
         self._logger = logging.getLogger()  # Logger object
@@ -95,7 +105,15 @@ class TcsClient:
         self.selected_instrument = None     # Current selected instrument
         self.automatic_mount = False        # Current mount state (automatic/manual)
 
-        self._scln = SclnClient(self._host, self._port)
+        self._scln = SclnClient(
+            self._host,
+            self._port,
+            timeout=self._timeout,
+            max_tx_retries=max_tx_retries,
+            max_rx_retries=max_rx_retries,
+            max_reconnect_attempts=max_reconnect_attempts,
+            max_reconnect_on_message=max_reconnect_on_message
+        )
         self.infoa()
         self._logger.info(json.dumps(self.info, indent=4))
 
@@ -714,6 +732,41 @@ def get_args(arguments: Union[list, None] = None) -> Namespace:
                         dest='port',
                         help='Number with tcp/ip socket port of the TCS')
 
+    parser.add_argument('--timeout',
+                        action='store',
+                        type=float,
+                        default=1.5,
+                        dest='timeout',
+                        help='Default timeout')
+
+    parser.add_argument('--max-rx-retries',
+                        action='store',
+                        type=int,
+                        default=3,
+                        dest='max_rx_retries',
+                        help='Number of attempts to receive a message')
+
+    parser.add_argument('--max-tx-retries',
+                        action='store',
+                        type=int,
+                        default=12,
+                        dest='max_tx_retries',
+                        help='Number of attempts to send a message')
+
+    parser.add_argument('--max-reconnect-attempts',
+                        action='store',
+                        type=int,
+                        default=0,
+                        dest='max_reconnect_attempts',
+                        help='Number of attempts to connect the TCP socket')
+
+    parser.add_argument('--max-reconnect-on-message',
+                        action='store',
+                        type=int,
+                        default=5,
+                        dest='max_reconnect_on_message',
+                        help='Number of attempts to reconnect while receiving a message')
+
     args = parser.parse_args(args=arguments)
 
     if args.host is None or args.port is None:
@@ -733,7 +786,18 @@ def tcs_infoa(arguments: Union[list, None] = None):
     log = logging.getLogger()
 
     args = get_args(arguments=arguments)
-    tcs = TcsClient(args.host, int(args.port))
+    print("Creating tcs object")
+    print(args)
+    tcs = TcsClient(
+        args.host,
+        args.port,
+        timeout=args.timeout,
+        max_tx_retries=args.max_tx_retries,
+        max_rx_retries=args.max_rx_retries,
+        max_reconnect_attempts=args.max_reconnect_attempts,
+        max_reconnect_on_message=args.max_reconnect_on_message
+    )
+    print("Created")
 
     try:
         while not tcs.is_connected():
